import QtQuick
import QtWayland.Compositor
import QtWayland.Compositor.XdgShell

Item {
    id: container
    implicitWidth: 800
    implicitHeight: 480

    visible: model.currentRegion !== root.quickBarID && model.currentRegion !== ""
    signal surfaceDestroyed

    property real internalSpacing: settings.value("QuickBarElement/LabelSize") / 2

    function colorWithAlpha(color, alpha) {
        return Qt.hsla(color.hslHue, color.hslSaturation, color.hslLightness, alpha)
    }

    ShellSurfaceItem {
        id: shell
        width: parent.width
        height: parent.height
        shellSurface: modelShellSurface

        onWidthChanged: modelToplevel.sendFullscreen(Qt.size(width,height))
        onHeightChanged: modelToplevel.sendFullscreen(Qt.size(width,height))
        onSurfaceDestroyed: container.surfaceDestroyed()
    }

    Rectangle {
        id: decorationFrame
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
        }
        height: title.height + container.internalSpacing
        gradient: Gradient {
            orientation: Gradient.Horizontal
            GradientStop { position: 0; color: container.colorWithAlpha(Qt.color(settings.value("QuickBar/Color2")), 0.5) }
            GradientStop { position: 0.3; color: container.colorWithAlpha(Qt.color(settings.value("QuickBar/Color")), 0.1) }
            GradientStop { position: 0.5; color: "transparent" }
        }

        Text {
            id: title
            anchors {
                verticalCenter: parent.verticalCenter
                left: parent.left
                leftMargin: container.internalSpacing
            }
            color: settings.value("QuickBar/LabelColor")
            font {
                bold: settings.value("QuickBar/LabelBold")
                pixelSize: settings.value("QuickBar/LabelSize")
                family: settings.value("QuickBar/LabelFont")
            }
            text: name
        }

        Rectangle {
            id: decorationFrameShadow
            anchors {
                top: parent.bottom
                left: parent.left
                right: parent.right
            }
            height: 2
            gradient: Gradient {
                orientation: Gradient.Horizontal
                GradientStop { position: 0; color: "#cc000000" }
                GradientStop { position: 0.3; color: "#66000000" }
                GradientStop { position: 0.5; color: "transparent" }
            }
        }
    }
}
